package cn.com.ctop.kuaishou.modules.ai.service.impl;

import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.mapper.UserAllocationMapper;
import cn.com.ctop.common.module.service.ICtopOauthTokenService;
import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.common.module.utils.LoadFileUtil;
import cn.com.ctop.kuaishou.modules.ai.entity.KuaishouCrowdPack;
import cn.com.ctop.kuaishou.modules.ai.mapper.KuaishouCrowdPackMapper;
import cn.com.ctop.kuaishou.modules.ai.service.IKuaishouCrowdPackService;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaishouPopulationService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.util.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.UUID;

/**
 * 人群报表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-03-26
 */
@Slf4j
@Service
public class KuaishouCrowdPackServiceImpl extends ServiceImpl<KuaishouCrowdPackMapper, KuaishouCrowdPack> implements IKuaishouCrowdPackService {

    @Autowired
    private KuaishouCrowdPackMapper crowdPackMapper;

    @Autowired
    private ICtopOauthTokenService tokenService;

    @Autowired
    private IKuaishouPopulationService iKuaishouPopulationService;

    @Autowired
    UserAllocationMapper userAllocationMapper;

    @Value("${zip.local.download-path}")
    private String downloadPath;


    @Override
    public Result<Object> queryPageList(JSONObject request) {
        int pageNo = request.getInteger("pageNo");
        int pageSize = request.getInteger("pageSize");
        if (Check.isNull(pageNo)) {
            pageNo = 1;
        }
        if (Check.isNull(pageSize)) {
            pageSize = 10;
        }
        Long total = crowdPackMapper.getTotal(request);
        PageHelper.startPage(pageNo, pageSize, false);
        List<KuaishouCrowdPack> list = crowdPackMapper.queryPageList(request);
        PageInfo pageInfo = new PageInfo(list);
        pageInfo.setTotal(total);
        return Result.ok(pageInfo);
    }

    @Override
    public Result<Object> uploadCrowdPack(Integer type, String orientationName, Long accountId, String url) {
        StringBuffer path = new StringBuffer();
        path.append(downloadPath).append(DateUtils.getNowDate(DateUtils.WEB_FORMAT)).append("/").append(UUID.randomUUID().toString()).append("/");
        log.info("-------下载到服务器地址：{}", path.toString());
        String name = url.substring(url.lastIndexOf("/") + 1);
//        String newFileUrl = FilesUtil.writeFiles(path.toString(), url, name);
        String newFileUrl = LoadFileUtil.downLoadFromUrl(url, path.toString());
//        String newFileUrl = url;
        String md5 = null;
        try {
            md5 = LoadFileUtil.getMD5(newFileUrl);
        } catch (IOException e) {
            log.error("获取MD5签名失败", e);
        }
        CtopOauthToken token = tokenService.getTokenByAccountId(accountId);
        JSONObject jsonObject = iKuaishouPopulationService.updatePopulation(token, type, orientationName, newFileUrl);
        if (jsonObject.getInteger("code") == 0) {
            KuaishouCrowdPack crowdPack = JSONObject.toJavaObject(jsonObject, KuaishouCrowdPack.class);
            crowdPack.setSignature(md5);
            crowdPack.setUrl(url);
            this.save(crowdPack);
        }
        return null;
    }

    @Override
    public Result<Object> accountPush(JSONObject request) {
        return null;
    }
}
